PhantomTextLine

Struct PhantomTextLine 

pub struct PhantomTextLine {
    pub text: SmallVec<[PhantomText; 6]>,
}
Information about the phantom text on a specific line.

This has various utility functions for transforming a coordinate (typically a column) into the resulting coordinate after the phantom text is combined with the line’s real content.

Fields

text: SmallVec<[PhantomText; 6]>

This uses a smallvec because most lines rarely have more than a couple phantom texts

Implementations

Source

impl PhantomTextLine

pub fn col_at(&self, pre_col: usize) -> usize

Translate a column position into the text into what it would be after combining

pub fn col_after(&self, pre_col: usize, before_cursor: bool) -> usize

Translate a column position into the text into what it would be after combining

If before_cursor is false and the cursor is right at the start then it will stay there (Think ‘is the phantom text before the cursor’)

pub fn col_after_force(&self, pre_col: usize, before_cursor: bool) -> usize

Translate a column position into the text into what it would be after combining

it only takes before_cursor in the params without considering the cursor affinity in phantom text

pub fn col_after_ignore( &self, pre_col: usize, before_cursor: bool, skip: impl Fn(&PhantomText) -> bool, ) -> usize

Translate a column position into the text into what it would be after combining

If before_cursor is false and the cursor is right at the start then it will stay there

(Think ‘is the phantom text before the cursor’)

This accepts a PhantomTextKind to ignore. Primarily for IME due to it needing to put the cursor in the middle.

pub fn before_col(&self, col: usize) -> usize

Translate a column position into the position it would be before combining

pub fn combine_with_text<'a>(&self, text: &'a str) -> Cow<'a, str>

Insert the hints at their positions in the text

pub fn offset_size_iter( &self, ) -> impl Iterator<Item = (usize, usize, usize, &PhantomText)>

Iterator over (col_shift, size, hint, pre_column) Note that this only iterates over the ordered text, since those depend on the text for where they’ll be positioned

pub fn apply_attr_styles(&self, default: Attrs<'_>, attrs_list: &mut AttrsList)